@@ -8,7 +8,9 @@ use Data::Validate::IP;
 use Exporter qw( import );
 use Test::More 0.88;
 
+## no critic (Modules::ProhibitAutomaticExportation)
 our @EXPORT = 'run_tests';
+## use critic
 
 my $object = Data::Validate::IP->new();
 
@@ -113,6 +115,9 @@ my %ipv6_types = (
     ],
 );
 
+my %ip_types = map { $_ => [ @{ $ipv4_types{$_} }, @{ $ipv6_types{$_} } ] }
+    qw( linklocal loopback multicast private public );
+
 sub run_tests {
     _ipv4_basic_tests();
     _type_tests(\%ipv4_types, 4);
@@ -120,6 +125,10 @@ sub run_tests {
 
     _ipv6_basic_tests();
     _type_tests(\%ipv6_types, 6);
+
+    # Tests for subs without a family
+    _ip_basic_tests();
+    _type_tests(\%ip_types);
 }
 
 sub _ipv4_basic_tests {
@@ -137,6 +146,7 @@ sub _ipv4_basic_tests {
 
     my @invalid_ipv4 = (
         qw(
+            2067:fa88::0
             www.neely.cx
             216.17.184.G
             216.17.184.1.
@@ -260,7 +270,7 @@ sub _ipv6_basic_tests {
             g123::1234
             :abcd
             ),
-        "::1\0 invalid"
+        "::1\0 invalid",
     );
 
     for my $ip (@invalid) {
@@ -279,6 +289,29 @@ sub _ipv6_basic_tests {
     }
 }
 
+sub _ip_basic_tests {
+    my @valid = qw( 1.1.1.1 2067:fa88::0 ::1.1.1.1 );
+
+    for my $ip (@valid) {
+        is(is_ip($ip),          $ip, "is_ip($ip) returns $ip");
+        is($object->is_ip($ip), $ip, "->is_ip($ip) returns $ip");
+
+    }
+
+    my @invalid = (
+        qw(
+            2067:fa88
+            216.17.184
+            :216.17.184
+            ),
+        "::1\0 invalid"
+    );
+    for my $ip (@invalid) {
+        is(is_ip($ip),          undef, "is_ip($ip) returns undef");
+        is($object->is_ip($ip), undef, "->is_ip($ip) returns undef");
+    }
+}
+
 sub _type_tests {
     my $types     = shift;
     my $ip_number = shift;
@@ -303,6 +336,7 @@ sub _type_tests {
                 my ($other_sub_name, $other_sub)
                     = _sub_for_type($other, $ip_number);
 
+                ## no critic (Subroutines::ProtectPrivateSubs)
                 if (Data::Validate::IP::_network_is_subnet_of($type, $other))
                 {
                     is(
@@ -333,8 +367,11 @@ sub _sub_for_type {
     my $type      = shift;
     my $ip_number = shift;
 
-    my $sub_name = 'is_' . $type . '_ipv' . $ip_number;
-    my $sub      = do {
+    my $sub_name = 'is_' . $type . '_ip';
+    $sub_name .= 'v' . $ip_number if defined $ip_number;
+
+    my $sub = do {
+        ## no critic (TestingAndDebugging::ProhibitNoStrict)
         no strict 'refs';
         \&{$sub_name};
         }
